#
# spec file for package tig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tig
Version:        2.5.12
Release:        1.3
Summary:        An ncurses-based text-mode interface for git
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://jonas.github.io/tig/
Source0:        https://github.com/jonas/tig/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  readline-devel >= 6.3
BuildRequires:  pkgconfig(libpcre2-posix)
BuildRequires:  pkgconfig(ncurses)
Requires:       git-core

%description
Tig is a git repository browser that additionally can act as a pager
for output from various git commands.

When browsing repositories, it uses the underlying git commands to
present the user with various views, such as summarized revision log
and showing the commit with the log message, diffstat, and the diff.

Using it as a pager, it will display input from stdin and colorize it.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -p1

%build
%configure \
	--with-ncurses \
	--docdir=%{_docdir}
%make_build

%install
%make_install install-doc-man
install -Dpm 0644 contrib/tig-completion.bash \
  %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dpm 0644 contrib/tig-completion.bash \
  %{buildroot}%{_datadir}/zsh/site-functions/%{name}-completion.bash
install -Dpm 0644 contrib/tig-completion.zsh \
  %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%files
%license COPYING
%doc NEWS.adoc README.adoc
%doc contrib/*.tigrc
%{_bindir}/tig
%config %{_sysconfdir}/tigrc
%{_mandir}/man1/tig.1%{?ext_man}
%{_mandir}/man5/tigrc.5%{?ext_man}
%{_mandir}/man7/tigmanual.7%{?ext_man}

%files bash-completion
%license COPYING
%{_datadir}/bash-completion

%files zsh-completion
%license COPYING
%{_datadir}/zsh

%changelog
* Fri Feb  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 2.5.12:
  * Fix empty blame view when opened from the diff view on i586. (#1362)
* Fri Jan 31 2025 Michael Vetter <mvetter@suse.com>
- Update to 2.5.11:
  Incompatibilities:
  * Update remote repo variables. (#1358)
  Bug fixes:
  * Fix various issues with diff.noprefix and --no-prefix.
  * Fix Ctrl-C behavior within the Readline prompt. (#1342)
  * Fix message upon edit from diffstat without patch.
  * Fix missing dates in the refs view.
  * Don't report an error when diff-highlight is killed intentionally.
  * Fix parsing of reflog designator in timestamp format.
  Improvements:
  * Open the blob corresponding to the diff line. (#1334)
  * Keep cursor position in the main view when toggling
    file-filter and rev-filter.
  * Make errors visible in views showing Git output. (#1346)
  * Allow different colors for all references types.
  * Enable search in sections titles. (#1043)
  * Show committer date by default in the date column. (#294)
  * Update utf8proc to v2.10.0, supporting Unicode 16.
  * Only show stash, notes and prefetch in the refs view when
    invoked with tig refs --all. (#1359)
* Sun May 12 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2.5.10:
  * Fix stat-* coloring file names in tig status instead of just
    markers (regression in 2.5.9)
  * Fix keybinding with +[cmd] not triggering view refreshing
  * Fix reopening the blame view from the main view
  * Fix editing when stdin is redirected
  * Make Ctrl-C to kill only the command running in the foreground
* Mon Apr  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.5.9:
  Improvements:
  * Update utf8proc to v2.9.0, supporting Unicode 15.1.
  * Also use lightweight tags in the Refs line of the diff view. (#1235)
  * Support %%(text) in all views with a text column. (#1275)
  * Use HTTPS for GitHub clone URLs. (#1310[3])
  * Move default log view options to tigrc.
  * Allow to go to stage view without Enter. (#1284)
  * Add new "prefetch" reference type for refs created by git maintenance
    (hidden in default config). (#1318)
  * Show the selected commit in the blame view title window.
  * Improve the blob view experience.
  * Clear keybinding from all keymaps (unbind) with bind generic <key> none.
  Bug fixes:
  * Fix "dangling pointer" warning. (#1268)
  * Don't use array size in function arguments. (#1269)
  * Fix rpmbuild -ta. (#1276)
  * Initialise struct timezone. (#1291)
  * Fix NULL dereference at startup. (#1293)
  * Enforce a blank before view scroll percentage.
  * Fix refresh-mode periodic not updating branch labels. (#1270)
  * Fix display non-ascii character. (#1299)
  * Fix readline echo when stdin is redirected. (#1229)
  * Fix tig blame --reverse. (#1300)
  * Fix status view lockup.
  * Fix untracked changes and chunk staging behaviour in plain stage view.
  * Reset state variables when selecting a commit with no reference.
  * Fix parsing of git ls-tree for submodules. (#1282)
* Mon Feb  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.5.8:
  Improvements:
  * Update utf8proc to v2.8.0, supporting Unicode 15.
  * Support editing from the pager and the log (-p) views. (#1243)
  * Adjust build for native Apple Silicon.
  * Autoscroll the pager view while loading. (#1223)
  * Automatically show next diff in the status view. (#413, #469)
  * Replace Unknown author with Not Committed Yet.
  * Allow use of regular expressions for coloring. (#1249)
  * Add support for option word-diff-regex. (#1252)
  * Include original blob name in temporary filename. (#1254)
  Bug fixes:
  * Use %%(file_old) for old filename in the blame view. (#1226)
  * Correctly report which version of libncurses was linked. (#1240, #1241])
  * Fix stage view closing when holding the ] key. (#1245)
  * Make tests work from a path with symlinks.
  * Fix encoding of very long lines. (#1227)
  * Fix diffstat color for tig log -p.
  * Clean IO before closing a view or quitting.
* Fri Aug 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.5.7:
  * Fix running tests as root. (#1224)
  * Fix parsing of status.showUntrackedFiles. (#1219)
  * Avoid incorrect history path when $XDG_DATA_HOME is valid. (#1215,
    [#1217])
* Wed Jul 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- tig 2.5.5 added pcre2 support. Actually build with it.
- fix bash and zsh completion packaging for Factory
* Wed Jul 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.5.6:
  * Fix :goto <tag>. (#1178)
  * Fix typo in ui.c.
  * Revert terminal hacks and workarounds. (#748, #943, #1180, #1182)
  * Fix opening of an ambiguous ref in refs view.
  * Fix search when view is loading.
  * Use the full width for diffstat in the stage view.
  * Improve escaping of variables in external commands.
  * Fix cursor behaviour during staging. (#842, #1028)
  * Fix navigation in split tree view.
  * Enable textconv in the stage view.
  * Enable textconv in the blame view and fix blame -L. (#978, #1189)
  * Update lineno for untracked files. (#1192)
  * Fix alignment of transliterated text. (#1195)
  * Fix word diff in the stage, stash and blame views. (#1207)
  * Fix reading the value of status.showUntrackedFiles. (#1211)
  * Honor commit_title:no in view settings.
  * Fix segfault with PCRE.
* Sun Jun 26 2022 Timothy Brown <stimut@gmail.com>
- Split out tig-bash-completion package
  * Removes dependency on bash-completion from main tig package
- Add tig-zsh-completion package
* Thu Jan 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.5.5:
  Improvements:
  * Make word-diff a toggleable option. (#1119, #1125)
  * Add Linux installation instructions. (#1121, #1126)
  * Allow :back to work across separate blame views. (#1123, #1127)
  * Add auto-refresh to log view. (#1128)
  * Expose %%(file_old), useful for deleted and renamed files. (#1132)
  * Enable jumping back in main view. (#628, #1138)
  * Add PCRE (Perl Compatible Regular Expressions) support. (#1137, #1143)
  * Pass command line args through to diff-files in status view. (#1152, #1155)
  * Remove quotes from TIG_LS_REMOTE to allow inline shell commands. (#1160,
    [#1161])
  * Avoid pushing identical history state in main view.
  * Replace useless strncpy to avoid compilation warning with GCC 8.
  * Update utf8proc to v2.7.0.
  * Update distclean rule to preserve tarball contents. (#1167, #1169)
  * Add reference types stash and other. (#1160, #1172)
  * Auto refresh view upon option change.
  * Allow to toggle revision filtering. (#1173)
  Bug fixes:
  * Fix null dereferences on unset format strings. (#1136, #1159)
  * Fix invalid read in log_read. (#1128)
  * Restore support for tig log --graph. (#1128)
  * Further fix to fullscreen navigation.
  * Fix blame when opened from an initial diff view. (#1135)
  * Fix stash view when using tig --all or tig revs. (#1146, #1147)
  * Avoiding null pointer dereference. (#1096)
  * Fix navigation between chunks after splitting chunk. (#1101, #1162)
  * Fix status line when toggling general options. (#1163, #1164)
  * Honor reference-format = hide:tag in diff view. (#1168, #1170)
  * Fix crash on :toggle file-args.
* Mon Jun  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.5.4:
  Improvements:
  * Add FreeBSD installation instructions. (#1093)
  * Add TIG_EDITOR environment variable to configure editor. (#889, #1098)
  * Enable mailmap by default to match git log's behaviour. (#1104, #1105)
  * Enable tilde expansion for diff-highlight. (#1107)
  Bug fixes:
  * Escape variables with %%%% in external commands. (#1091, #1095)
  * Fix parsing of -L argument. (#1100)
  * Bugfix: smart-case does not work when search term contains a space. (#1108)
  * Use ncursesw by default on Linux. (#920)
  * Replace obsolete macro `AC_CONFIG_HEADER' in configure.ac.
* Mon Mar  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.5.3:
  * Fix autoconf checking for readline. (#1072)
  * Fix segfault when saving a view with no column.
  * Reset view->parent when main view is promoted.
  * Fix segfault when pressing Enter in a child main view.
  * Restore lazy navigation.
  * Format time_t values portably and fix other values too. (#1084, #1085)
  * Fix loop when wrapping line with ISO-8859-1 character. (#1087, #1088)
* Sat Feb 13 2021 Andreas Stieger <andreas.stieger@gmx.de>
- tig 2.5.2:
  * Incompatible change: Change directory from the next argument,
    from now use tig -C /path/to/repo
  * Can now jump from blame to commit
  * Start blame of an uncommitted deleted line from HEAD so the
    line's origin can be traced
  * Allow maxwidth to be expressed in %% of the view width
  * Pass stash args through
  * Restore fullscreen navigation
  * Add some range so control chars ^^ and ^_ are also supported
  * Disable ncurses extended key values so that esc-codes can be used
  * Use id column for commit id only
  * Improvements to scrolling and clicking
  * Allow to generate a compilation database
  * New command stage-update-part
  * The line number before a diff was applied is exposed as
    %%(lineno_old)
  * Many bug fixes
* Sun Apr 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.5.1:
  Improvements:
  * bash/zsh completion: reimplement and decrease runtime by factor 1863.
  (#795)
  * Add binding to reflog view to toggle reference display.
  * Fail if tig is given an invalid or ambiguous ref. (#980)
  * Make tig process-group leader an option. (#986, #951)
  * Handle GIT_WORK_TREE environment variable.
  * The blame view requires a working tree.
  * Fix use of deprecated vwprintw() function.
  * Update utf8proc to v2.5.0.
  * Add --word-diff=plain colorizing support. (#221)
  Bug fixes:
  * Fix segmentation fault. (#971)
  * Fix cursor position after "Move to parent" in blame view. (#973)
  * Fix crash on adding a line to a view. (#523)
  * Fix memory leak in diff unit.
  * Fix loop after refresh or change in refs/main split view. (#991)
  * Fix occasional crash on custom key bindings. (#1001)
* Wed Nov 20 2019 Michael Vetter <mvetter@suse.com>
- Update to 2.5.0:
  Improvements:
  * Single file view enters blame mode on "b". (#804)
  * Show untracked files in the default view. (#762)
  * Disable graph if log.follow is enabled and there is only one pathspec. (#881)
  * Disable graph for author searches.
  * git_colors: interpret 'ul' as 'underline'.
  * Add refname variable. (#900)
  * Add -C option to specify the working directory. (#570)
  * Improve behaviour of auto and periodic refresh modes. (#389, #441, #482, #794, #888, #932)
  * Add support for repos created with git --work-tree. (#872)
  * Add diff-highlight to pager mode.
  * Show annotated commits in main view. (#819)
  * Introduce reflog view. (#538)
  * Add option to start with cursor on HEAD commit. (#755)
  * Support combined diffs with more than 2 parents.
  * Improve how a toggle option value is shown on the status line. (#879)
  * Add options to filter refs output. (#694)
  * Update utf8proc to v2.4.0. (#961)
  Bug fixes:
  * Fix garbled cursor line with older ncurses versions.
  * Fix diff highlighting of removed lines starting with -- and added lines
  * starting with ++. (#871, #875)
  * Fix loop when displaying search result if regex matches an empty string. (#866)
  * Add synchronous command description in tigrc.
  * Fix parsing of git rev-parse output. (#884)
  * Propagate --first-parent to diff arguments. (#861)
  * Use proper type for hash table size. (#858)
  * Fix incorrect cppcheck warning about realloc() use.
  * Don't shift signed int by 31 bits.
  * Fix Vim going background after running Tig outside of a git repository. (#906)
  * make-builtin-config: use "read -r". (#912)
  * Fix segfaults with readline 8.0. (#893)
  * Reset state before closing stage view automatically.
  * Don't use a child view as previous view.
  * Force reload of VIEW_FLEX_WIDTH views only when needed.
  * Combined diff uses @@@ as hunk marker.
  * Fix memory leak induced by 'tig grep'.
  * Fix memory leak in main view.
  * Exit gracefully if refs view was defined without ref column. (#897)
  * Fix pager view not moving up when child view is open.
  * make-builtin-config: Fix unportable sed usage in read_tigrc().
  * Properly detect combined diffs. (#942)
* Fri Jul 27 2018 mpluskal@suse.com
- Make building more verbose
- Small adjustments with spec-cleaner
- Install bash completion to correct location
* Fri Jul 27 2018 mvetter@suse.com
- tig 2.4.1:
  * Add CURSES_CFLAGS to CPPFLAGS. (#856)
* Sun Jul 22 2018 astieger@suse.com
- tig 2.4.0:
  * blame view now renders more like git-blame
  * Improve worktree and submodule support
  * Support running Tig via a Git alias
  * Use ISO-8601 letters for short relative dates
  * Change date formatting to show time zones by default
  * Use utf8proc to handle Unicode characters
  * a number of bug fixes
* Sun Feb 18 2018 avindra@opensuse.org
- tig 2.3.3:
  * Fix 100%% CPU when closing terminal window before quitting tig
    by catching SIGHUP.
  * Change refs_tags type to size_t.
  * Revert "Handle \n like \r (#758)" from 2.3.1
* Sat Dec 23 2017 avindra@opensuse.org
- tig 2.3.2:
  * Improve how busy loop detection performs on large repos
- tig 2.3.1:
  * Improvements:
  - Restore TTY attributes
  - Handle \n like \r
  * Bug fixes:
  - Add workaround that detects busy loops when Tig loses the
    TTY. This may happen if Tig does not receive the HUP signal
    (e.g. when started with nohup)
  - compatibility with ncurses-5.4 (clipboard support for prompt)
  - tig(1): document correct environment variable
- use macros to simplify build and install steps
* Fri Sep 29 2017 astieger@suse.com
- tig 2.3.0:
  * The `width` setting on the `status`, `text` and `commit-title`
    columns was never applied and has been removed
  * improve load performance and rendering speed
  * Enable binding to more symbolic keys and keys with control
    modifier
  * Store and readline history on disk
  * Various bug fixes
- drop upstreamed patches:
  * tig-remove_build_timestamp.patch, reproducible.patch
* Sat May  6 2017 astieger@suse.com
- tig 2.2.2:
  * The status-untracked-dirs option was renamed to
    status-show-untracked-dirs to match the new
    status-show-untracked-files option.
  * Use diff-options when preparing the diff in the stage view to
    make the diff state configurable
  * Add 'status-show-untracked-files' option mirroring Git's
    'status.showUntrackedFiles' to toggle display of untracked
    files in the status view. On by default
  * Update ax_with_curses.m4 and use pkg-config to detect
  * Add tig-pick script for using Tig as a commit picker
  * Add "smart case" option ('set ignore-case = smart-case') to
    ignore case when the search string is lower-case only
  * Fix author ident cache being keyed by email only.
  * Fix periodic refresh mode to properly detect ref changes.
  * Add workaround for detecting failure to start the
    diff-highlight process.
  * Show diffs in the stash view when set mailmap = true
  * Fix parsing of git-log revision arguments, such as
  - -exclude=... in conjunction with --all
  * Fix diff stat parsing for binary copies
  * Fix crash when resizing terminal while search is in progress
  * Fix argument filtering to pass more arguments through to Git
  * Check for termcap support in split tinfo libs
* Sat Mar 11 2017 mimi.vx@gmail.com
- spec-cleaned
* Mon Jan 23 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Thu Nov 17 2016 astieger@suse.com
- tig 2.2.1:
  * Support Git's 'diff-highlight' program when diff-highlight is
    set to either true or the path of the script to use for post-
    processing.
  * Add navigation between merge commits
  * Add 'A' as a binding to apply a stash without dropping it.
  * Bind 'Ctrl-D' and 'Ctrl-U' to half-page movements by default.
  * manual: Mention how to change default Up/Down behavior in diff view.
  * Fix :goto <id> error message.
* Sat Aug 13 2016 astieger@suse.com
- tig 2.2
  * incompatible changes:
    + user-defined commands are now executed at the repository root
    + Remove `cmdline-args` option
  * new features:
    + mailmap to show canonical name and email addresses
    + configurable highlight of search results
    + external commands improvements
    + UI improvements
  * various bug fixes
* Thu Apr  9 2015 astieger@suse.com
- tig 2.1.1
- improvements
  * Add support for key combos.
  * See `contrib/vim.tigrc` for Vim-like keybindings.
  * Add GitHub inspired file finder to search for and open any file.
  * Add `search` keymap for navigation file finder search results.
- Bug fixes:
  * Fix display of multiple references per commit.
  * Sync the prompt's cursor position with readline's internal position.
  * Keep unstaged changes view open after an staging command.
* Fri Mar 13 2015 astieger@suse.com
- package bash completion
- package some configuration files samples
- use upstream spec.in description
* Wed Mar 11 2015 astieger@suse.com
- tig 2.1:
  * navigation updates and fixes
  * UI improvements
  * speed improvements
  * Add :exec prompt command
  * Add :save-options prompt command
  * documentation updates
- Replace tig-fix-build.diff, autoconf call with configure option
- use make install-doc
- build with readline support
* Fri Aug 29 2014 multyrealm@gmail.com
- update to 2.0.3
  * Improvement:
  - Add `:save-display <file>` prompt command to save the current display.
  - Add `:script <file>` prompt command for scripting the Tig UI.
  - Add test framework and convert existing tests to use it.
  - Add command-line option for starting in refs view: `tig refs`. (GH #309)
  - Make blame commit ID colors stable across reloads. (GH #303)
  - Increase blame ID and graph rendering color palette to 14 colors.
  - New setting 'split-view-width' controls the width for vertical splits. It
    takes the width of the right-most view either as a number or a percentage.
  - Expose settings holding command line argument lists: `file-args`, `rev-args`,
    and `cmdline-args`. They are mainly intended for testing purposes but also
    allows to change the filtering arguments dynamically. (GH #306)
  - Add `log-options` setting for specifying default log view options.
    Example: `set log-options = --pretty=fuller`.
  - Use option specific view flags to reload view after `:set` commands.
  * Bug fixes:
  - Refresh the current view when returning from an external command and
    `refresh-mode=after-command`. (GH #289)
  - Fix readline completion.
  - Fix '/' to `find-next` when readline support is enabled. (GH #302)
  - Fix readline prompt to correctly handle UTF-8 characters.
  - Add warnings for more obsolete actions and colors.
  - Fix passing of commit IDS via stdin to the main view.
  - Fix commit title overflow drawing for multibyte text. (GH #307)
  - Fix installation directory permissions.
  - Handle binary files matches reported by git-grep.
  - Toggling of "args"-typed options without any arguments will clear the current
    arguments. Example: `:toggle blame-options`.
  - Detect custom `pretty.format` settings that break the log view and fallback
    to use the `medium` format. (GH #225)
  - Fix invocation of git-diff for the blame view's line tracking. (GH #316)
  - Fix blame completion of directory names. (GH #317)
  - Fix display of conflicts in the main view when 'show-changes' is enabled.
  - Fix off-by-one error when displaying line numbers in the grep view.
  - When showing the commit graph ensure that either topo, date or author-date
    commit order is used. (Debian #757692) (GH #238)
* Sat May 31 2014 bernhard@bwalle.de
- update to 2.0.2
  * Improvements
  - Use git-status for diffing the index.
  - Group toggle options together in the help view.
  * Bug fixes
  - Fix refs, main and grep loading when gui.encoding is set.
  - Ignore gui.encoding and i18n.commitencoding when set to UTF-8.
  - Add work-around for missing strndup() on Mac OS X v10.6.
  - Fix spurious abbreviation of author names.
  - Don't show empty action groups in the help view.
- update to 2.0.1
  * Bug fixes:
  - Fix compilation in watch.c.
  - Fix parsing of key bindings mapped to ^ and <.
- update to 2.0
  * Incompatibilities
  - In preparation for key combo support, key mappings for symbolic
    keys (e.g. Up and Down) must now start with < and end with >,
    e.g. <Up> and <Down>.  Furthermore, escape key combos must
    now use <Esc>key instead of ^[key, and control key mappings
    must now use <Ctrl-key> instead of ^key.
  - Only use diff-options for the diff view and introduce
    %%(cmdlineargs) to hold non-file and non-revision flags passed
    on the command line. Affects all user-defined commands that
    expect %%(diffargs) to hold both diff-options arguments and
    those passed on the command line.
  - Remove built-in keybinding for git gc. Add the following line
    to ~/.tigrc to restore it: bind generic G ?git gc.
  - To support view specific colors, . can no longer be used
    interchangeably with - and _ in settings names and in particular
    color names.
  - Replace stage-next action with prompt command using a predefined
    search (see below) and add binding (@ by default) to also work
    in the diff view.
  - Most view display options must now be set via the new *-view
    options in tigrc. Existing options are no longer recognized,
    but a warning is shown.
  - Remap default bindings to have more consistent convention:
    use lower-case keys primarily for view switching and
    non-destructive actions, use upper-case keys for view-specific
    actions including user-defined commands. To preserve old default
    key bindings see contrib/bindings-v1.x.tigrc.
  * Improvements
  - Add mouse support: scroll view, click line to move cursor, double
    click line (or click again) to "Enter" cursor line, e.g. open
    commit diff. Disabled by default, since it makes text selection
    less intuitive. If you enable this remember to hold down Shift
    (or Option on Mac) when selecting text.
  - Rewrite and improve the rendering of the commit graph.
  - Add completion and history support to the prompt via readline.
  - Options can be configured and toggled individually for each view.
    Use the new view settings to configure the order and display
    options for each view columns. See system tigrc and tigrc(5) for
    examples.
  - Add grep view as a front-end to git-grep(1): tig grep -p strchr.
    From within Tig, the key for switching or grepping is bound to g
    by default.
  - Rename branch view to refs view and show tags. (GH #134)
  - Add main view pager mode that reads git-log’s --pretty=raw data
    from stdin, e.g. git reflog --pretty=raw | tig --pretty=raw.
  - Add support for --graph and highlight diff stats in the log view.
  - Add default command bindings: ! to delete branch, ! to drop stash.
  - Add stage-split-chunk action for splitting chunks in the stage
    view. Bound to \ by default.
  - Add back action bound to < by default, which will return the blame
    view to the previous revision and line after moving e.g. to the
    parent.
  - Auto-refresh views based on watched repository changes. Configure
    by setting refresh-mode to manual, auto, after-command, or periodic.
  - All default settings are in well-documented system tigrc.
  - Add :toggle prompt command to manipulate options using keybindings.
    For example: bind diff D :toggle diff-options --patience --notes.
  - Add a new "auto" value for the vertical-split option to let Tig
    choose the split orientation (this is the new default behavior).
    Can be toggled.
  - Make it possible to toggle the display of files in untracked
    directories.
  - Allow Tig to be started with no default configuration by specifying
    an alternative system tigrc file, e.g.: TIGRC_SYSTEM=~/.tigrc.safe
    tig. Set TIGRC_SYSTEM to the empty string to use built-in
    configuration instead of
  - Key mappings can contain UTF-8 multibyte unicode keys.
  - Warn about conflicting keybindings using Ctrl, e.g. <Ctrl-f> and
    <Ctrl-F>.
  - Extend key bindings for prompt commands (ie. bind <keymap> <key>
    :<prompt>) to support predefined searches, eg.: bind stage 2 :?^@@.
  - Git color mappings can be configured in tigrc.
  - More informative configuration error messages.
  - Make reference label formatting configurable, for example:
    set reference-format = (branch) <tags> remote.
  - Adjust author width and other view columns automatically.
  - Support view specific colors: color stage.diff-add yellow default.
  - Copy -S, -G and --grep= pattern to search buffer so find-next and
    find-prev work as expected.
  - Optionally specify custom prompt for %%(prompt) in shell commands,
    e.g. bind main B ?git checkout -b "%%(prompt Enter new branch name: )".
  - Add %%(remote) and %%(tag) symbols to complement %%(branch).
  - User-defined commands can now be prefixed with any of the supported
    flags, e.g. ?git checkout -b %%(branch).
  - Open editor at line number for combined diffs e.g. diffs of unmerged files.
  - Add build configuration for Cygwin (OS name: CYGWIN_NT-6.1).
  - Document the Git commands supported by the pager mode. system
    tigrc configuration.
  * Bug fixes
  - Fix stash diff display when reloading the stash view after a deleting.
  - Set the commit reference when opening the blame view from the blob view.
  - Correctly identify and highlight the remote branch tracked by HEAD.
  - Pass --no-color after user defined arguments to ensure that colors do
    not break the output parsing.
  - Close stdin when pager mode is not supported.
  - Show newly created branches in the main view.
  - File with 0 changes breaks diffstat highlighting
  - Update %%(branch) variable in the main view.
  - Disable graph rendering when either of --reverse, -S, -G, and
  - -grep are passed to the main view.
  - Only refresh views that support it.
  - Fix author and date annotation of renamed entries in the tree view.
  - Fix use of unsafe methods in the signal handler.
  - Fix rendering in non-UTF8 terminals.
  - Fix stage-update-line by rewriting the diff chunk containing the line
    instead of using --unidiff-zero and a diff context of zero.
  - Fix status-update to work for untracked directories.
  - Don't pass log parameters given on the command line to the diff view.
- adjust patches to new version
* Wed Sep 18 2013 speilicke@suse.com
- Use pristine upstream tarball
* Mon Sep 16 2013 multyrealm@gmail.com
- change autogen.sh call to autoreconf
* Thu Sep  5 2013 multyrealm@gmail.com
- convert asciidoc files to man pages
* Tue Sep  3 2013 multyrealm@gmail.com
- update to 1.2.1
  * Incompatibilities:
  - Move manual and man pages to doc/ directory and rename AsciiDoc files
    to have .asciidoc as the extension to make them render on GitHub.
  * Improvements:
  - Show blob sizes in the tree view either as bytes or using binary unit
    prefixes. Example: `set show-file-size = units`. (GH #163)
  - Reduce main view memory usage and startup time, especially when revision
    graph rendering is disabled. (GH #160)
  * Bug fixes:
  - Fix submodule-related setup to check for non-zero return value from
    setenv(). (GH #188)
* Sat Aug 10 2013 pascal.bleser@opensuse.org
- update to 1.2:
  * Improvements:
    + Make tig prompt commands bindable to keys. For example: `bind diff F :set
    diff-options = --full-diff`. (GH #69, #116)
    + Add a diff-options setting for specifying default diff options.
    Example: `set diff-options = --patience`. (GH #116)
    + Options in diff-options and blame-options matching tig browsing state
    variables are replaced.
    + Show diff stats as wide as the terminal. (GH #109)
    + Show line numbers in the branch view. (GH #135)
    + Add toggles for showing author email or email user names. (GH #115)
    + Open editor at the selected line by prefixing the file argument with
    `+<lineno>`. Tested in vi, vim, emacs, nano, gedit, geany. Disable
    by adding `set editor-line-number = no` to ~/.tigrc. (GH #118, #119)
    + Add toggle-files to control whether to show full commit diff or only
    the diff concerning the currently selected file, e.g. for blame.
    + Optionally highlight exceeding characters in long commit titles.
    The default title max width is 50 characters. Customize using:
    `set title-overflow = 50` (GH #125)
    + Add +ESC key bindings. Example: `bind generic ^[v move-page-up` (GH #120)
    + Create temporary files in TMPDIR, TEMP, or TMP before defaulting to /tmp.
    + Reenable `tig log` as a subcommand. (GH #146)
    + Enable tilde expansion in ~/.tigrc "source" commands. (GH #168)
    + Introduce the stash view, bound to the 'y' keybinding. (GH #169, #174)
  * Bug fixes:
    + Fix blame and status to work in directories starting with a dot. (GH #172)
    + Reload current branch name when reloading the status view. (GH #93)
    + Fix compile errors on old Solaris. (GH #97)
    + Reload HEAD info when reloading the stage view. (GH #104, #93)
    + Fix disappearing branch labels after external commands. (GH #148)
    + Fix diff view display for staged/unstaged changes when using 'd'.
    + Fix display of status messages when toggling view options. (GH #111)
    + Fix illegal memory access. (GH #98)
    + Fix display of all branches label in repos with short branch names.
    + Fix rendering glitch for branch names.
    + Do not apply diff styling to untracked files in the stage view. (GH #153)
    + Fix tree indentation for entries containing combining characters. (GH #170)
    + Ignore unrepresentable characters when transliterating text for rendering.
    + Transliterate text to output encoding before trimming it to avoid
    misalignment. (GH #86)
    + Introduce a more natural context-sensitive log display. (GH #155)
* Sun Oct 14 2012 douglarek@outlook.com
- Updated to 1.1
    Incompatibilities:
  - Disable diff move/copy detection by default, boosting diff
    performance on larger projects. Use git config 'diff.renames' option
    (git-wide) to set your preferred behavior. Environment variable
    TIG_DIFF_OPTS can be used to restore the old behavior.
  - Values set for author-width and filename-width will result in widths
    one character bigger than previously.
    Improvements:
  - Typing a text in the prompt will be interpreted as a tig command.
    Prefixing the command with a '!' will execute this system command in
    an external pager. Entering a single key will execute the
    corresponding key binding.
  - Basic support for wrapping long line in pager, diff, and stage views.
    Enable using: `set wrap-lines = yes`. (GH #2)
  - User-defined commands prefixed with a '?' means prompt before
    execution. Example: `bind main B !?git rebase -i %%(commit)`.
  - User-defined commands prefixed with a '<' means exit after execution.
    Example: `bind main C !<git commit`. (GH #66)
  - User-defined commands are executed unquoted to support shell commands.
    Example: `bind generic I !@sh -c "echo -n %%(commit) | xclip -selection c"`.
    (GH #65)
  - Configure case-insensitive searches using: `set ignore-case = yes`.
  - Add "deleted mode" line type for better diff coloring.
  - Open editor when requesting edit action from within a file diff.
  - Update AX_WITH_CURSES to build under Cygwin.
  - Improve tigrc(5) documentation. (Debian #682766)
  - Allow to build on Mac OS 10.7 without the configure script. (GH #25)
  - Add option to split the view vertically instead of horizontally.
    Example: `set vertical-split = yes'. (GH #76)
  - Add 'show-id' and 'id-width' options to configure the display of
    commit IDs in the main view and ID width in the blame view. (GH #77)
  - Allow to override git-based encoding to UTF-8 by setting
    'i18n.commitencoding' or 'gui.encoding'.
  - Improve autobuild support to track generated files and work with
    autoreconf 2.61.
  - Commit IDs are read from stdin when --stdin is given; works for main
    and diff view, e.g. `tig --no-walk --stdin < cherry-picks.txt`.
  - Add option to disable focusing of the child view when it's opened.
    Disable using: `set focus-child = no`. (GH #83)
  - Allow to open blob related with added content in a diff. (GH #91)
    Bug fixes:
  - Fix commit graph regression when a path spec is specified. (GH #53)
  - Main view: only show staged/unstaged changes for the current branch.
  - Support submodules created with current version of git. (GH #54)
  - Fix diff status message for file diffs with no content changes.
  - Fix parent blaming when tig is launched in subdirectory. (GH #70)
  - Do not show deleted branch when reloading the branch view.
* Fri Aug 17 2012 bernhard@bwalle.de
- Link tig against ncursesw for correct display of non-ASCII
  characters like German umlauts.
* Fri May 11 2012 pascal.bleser@opensuse.org
- add patch to remove build timestamps
- update to 1.0:
  * Use git-log(1)s default commit ordering. The old behavior can be
    restored by adding `set commit-order = topo` to ~/.tigrc.
  * Support staging of single lines. Bound to '1' default. (GH #21)
  * Use +<lineno> to open the initial view at an arbitrary line. (GH #20)
  * Add show-notes ~/.tigrc option. Notes are displayed by default.
  * Support jumping to specific SHAs in the main view.
  * Decorate replaced commits.
  * Display line numbers in main view.
  * Colorize binary diff stats. (GH #17)
  * Custom colorization of lines matching a string prefix (GH #16).
    Example configuration: color "Reported-by:" green default
  * Use git's color settings for the main, status and diff views.
    Put `set read-git-colors = no` in ~/.tigrc to disable.
  * Handle editor options with multiple arguments. (GH #12)
  * Show filename when running tig blame with copy detection. (GH #19)
  * Use 'source <path>' command to load additional files from ~/.tigrc
  * User-defined commands prefixed with '@' are run with no console
    output, e.g. bind generic 3 !@rm sys$command
  * Make display of space changes togglable in the diff and stage view.
    Bound to 'W' by default.
  * Use per-file encoding specified in gitattributes(5) for blobs and
    unstaged files.
  * Obsolete commit-encoding option and pass --encoding=UTF-8 to revision
    commands.
  * Main view: show uncommitted changes as staged/unstaged commits.
    Can be disabled by putting `set show-changes = no` in ~/.tigrc.
  * Add %%(prompt) external command variable, which will prompt for the
    argument value.
  * Log information about git commands when the TIG_TRACE environment
    variable is set. Example: `TIG_TRACE=/tmp/tig.log tig`
  * Branch view: Show the title of the last commit.
  * Increase the author auto-abbreviation threshold to 10. (GH #49)
  * For old commits show number of years in relative dates. (GH #50)
  * Fix navigation behavior when going from branch to main view. (GH #38)
  * Fix segfault when sorting the tree view by author name.
  * Fix diff stat navigation for unmodified files with stat changes.
  * Show branches/refs which names are a substring of the current branch.
  * Stage view: fix off-by-one error when jumping to a file in a diff
    with only one file.
  * Fix diff-header colorization. (GH #15)
* Thu Feb 16 2012 saschpe@suse.de
- Add more detail about last version update
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Aug 31 2011 gregkh@suse.de
- remove test-graph from the spec file as it really isn't a program to ship.
* Tue Aug 30 2011 gregkh@suse.de
- update to 0.18:
  - Incompatibilities:
  * Remove support for the deprecated TIG_{MAIN,DIFF,LOG,TREE,BLOB}_CMD environment variables.
  - Improvements:
  * Pressing enter on diff stat file lines will jump to file’s diff.
  * Naïvely color blame IDs to distinguish lines.
  * Document palette color options used for revision graph and blame IDs.
  * Add support for blaming diff lines.
  * Add diff-context option and bindings to increase the diff context in the diff and stage view.
  * (GH-6) Make blame configurable via extra options passed from the command line and blame-options setting from ~/.tigrc. For example:
  * set blame-options = -C -C -C
  - Bug fixes:
  * Expand browsing state variables for prompt. (LP #694780, Debian #635546)
  * Fix segfault when sorting the branch view by author.
  * Expand %%(directory) to . for the root directory. (GH-3)
  * Accept utf-8 for the line-graphics option as indicated in the docs.
  * Use erasechar() to check for the correct backspace character.
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- spec file tidying
- update to 0.17:
  * an ncurses 2.8 issue was fixed by passing a non-zero column size to newwin
  * opening of diffs when browsing branches was improved
  * a rewritten revision graph renderer was added; three modes are supported:
    UTF-8, ncurses line graphics, and ASCII
  * revision graph rendering is enabled by default
* Wed Dec 15 2010 gregkh@suse.de
- update to 0.16.2
* Mon Jun 14 2010 bernhard@bwalle.de
- update to 0.16
  o Incompatibilities:
  - Encode everything internally as UTF-8. This can affect
    performance, but should in general improve handling of
    character lengths etc. Also, to properly handle UTF-8
    environments use ncurses with wide character support.
  - The use of TIG_{MAIN,DIFF,LOG,TREE,BLOB}_CMD environment
    variables has been deprecated. To allow configuration of the
    diff view, TIG_DIFF_OPTS can be used.
  o Improvements:
  - Plug several memory leaks.
  - Command line arguments are split into diff, revision, and
    file arguments and made available as %%(diffargs), %%(revargs),
    and %%(fileargs). Diff view will limit diffs using %%(fileargs).
  - Status view: update the file variable when a line is selected
    so %%(file) works as expected.
  - Branch view: add %%(branch) symbol providing access to the
    selected branch.
  - Branch view: add entry to browse all branches (uses git-log’s
  - -all flag).
  - Abbreviation of author names can now be configured and
    toggled.
  - Mark detached heads with [HEAD].
  - Add support for displaying dates in local time.
  o Bug fixes:
  - Status view: fix usage from sub directories, which was broken
    by the changes made to support blame view from sub
    directories.
  - Fix text expansion to not truncate long lines
  - Fix parsing of boolean show-date values.
  - Fix relative date.
  - Fix unbind to behave as if the keybinding was never defined.
  - Fix unbind to also cover built-in run requests.
  - Fix parsing of unknown keymap names.
  - Blame view: fix parent blame to detect renames. It uses
    "previous" line info from the blame porcelain output added in
    git version 1.6.3.
* Sun Dec 13 2009 bernhard@bwalle.de
- update to 0.15
  o Incompatibilities
  - Setting the cursor color no longer automatically sets the
    text to bold. The old lazy behavior was a bug.
  - Remove check for git-repo-config, which was officially
    deprecated in git version 1.5.4.
  o Improvements
  - Provide the manual as a man page named tigmanual(7).
  - Add ability to toggle between showing shorter dates (without
    time info) and relative dates.
  - Show the active (instead of the default) keybindings in the
    help view.
  - Add branch view for choosing which branch to display in the
    main view.
  - Tree view: show entry to parent directory (..) when running
    from subdirectory.
  - Tree view: sort entries by name, date or author.
  - Make height of the lower view in a split view configurable
    by setting the split-view-height variable to a number or a
    percentage.
  - Allow multiple text attributes for color commands:
    color cursor white blue underline bold
  o Bug fixes
  - Blame view: fix loading of blame data when opened from the
    tree view and CWD is not the repo root.
  - Tree view: fix searching.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Feb 20 2009 bwalle@suse.de
- update to 0.14.1
  o Improvements
  - Status view: improve "on branch" information inspired by the
    prompt code in git's bash completion script.
  - Colors for 256-capable terminals can be specified as colorN.
  - Entering a number in the prompt will jump to that line
    number.
  - Handle core.worktree by setting GIT_DIR and GIT_WORK_TREE.
  - Make behavior of horizontal scrolling configurable by setting
    the horizontal-scroll variable to a number or a percentage.
  o Bug fixes.
- update to 0.14
  o Incompatibilities:
  - The screen-resize action has been deprecated.
  - The "tree-parent" action was renamed to "parent". Warnings
    will be emitted for transition.
  - Remove parsing of deprecated option -S and subcommands log
    and diff.
  - The "author" color replaces "main-author".
  o Improvements:
  - Horizontal scrolling.
  - Read tigrc(5) options from git configuration files.
  - Tree view: avoid flickering when updating.
  - Tree view: annotate entries with commit information.
  - Tree & blob view: open any blob in an editor.
  - Stage & main view: restore view position when reloading.
  - Blame view: load blame for parent commit.
  - Abbreviate author names to initials when the width of the
    author column is below 6 characters.
  o Bug fixes
* Thu Jan 15 2009 bwalle@suse.de
- update to 0.13
  o Incompatibilities:
  - Commands from the environment (e.g. TIG_MAIN_CMD) will no
    longer have access to shell features, such as subshells and
    variable expansion.
  o Improvements:
  - Display repository references in the sorted order: tags,
    heads, tracked remotes, remotes.
  - Add bash completion for blame.
  - Tree view: edit files of the current branch.
  - Run requests: new identifiers %%(directory), %%(file), and
    %%(ref)
  - Improve responsiveness and view loading speed by using
    select(2).
  o Bug fixes:
  - Separate blame revision and file argument by "—" to avoid
  - Main view: fix redrawing of the last commit wrt. the revision
    graph.
  - Fix waiting for input after executing a run request in pager
    mode.
  - Status & stage view: refuse to open directories and deleted
    files.
  - Tree view: show error when requesting blame for all non-file
    entries.
  - Do not draw loading views, which are not displayed.
  - Fix launching of mergetool from a subdirectory problems.
* Thu Oct  9 2008 bwalle@suse.de
- update to 0.12.1
  o Improvements:
  - Status view: revert uncommitted diff chunks and unstaged
    files with changes. Bound to ! by default.
  - Main view: use —topo-order also when rev-list arguments are
    given on the command line.
  - Log view: support for refreshing.
  o Bug fixes:
  - Status view: use ls-files' —exclude-standard so user specific
    ignore rules are effective. The option was added in git
    version 1.5.4.
  - Stage view: fix assertion failure triggered when updating
    while status view is not displayed.
  - Help view: avoid confusion by showing "(no key)" instead of
    "?" for unbound requests.
  - Reload repository references when refreshing the main (and
    log) view.
  - Do not maximize views when refreshing.
* Mon Oct  6 2008 bwalle@suse.de
- update to 0.12
  o Improvements:
  - F5 also refreshes the current view.
  - Allow line graphics to be disabled with new line-graphics
    option
  - Main view: also include the reference names when searching
  - Main view: support for refreshing
  - Main view: disable boundary commits by default. Use —boundary
    when they should be shown
  - Stage view: add stage-next action to jump to next diff chunk
    that can be staged. By default bound to @
  - Configure: check for the ncurses header files
  - Add author-width option to costumize the width of the author
    column.
  o Bug fixes:
  - Fix regression when staging all diff chunks in a section.
  - Bind the maximize view action to O; it conflicted with the
    keybinding to launch the merge tool in the status view
  - Fix problem with $(cmd) usage in shell code. Some shells
    (jsh) installed as /bin/sh does not support it
  - Do not show incomplete boundary commits when —no-walk is used
  - Documentation: Rename gitlink macro to support AsciiDoc 8.2.3
  - Ignore pipe reads with errno "Success" reported after a
    signals, for example when refreshing doing background loading
* Mon Apr  7 2008 bwalle@suse.de
- update to 0.11
  o Fix pager mode and disable view reliance on the git directory.
  o The date and author columns and references can now be toggled
    on and off.
  o Local (unsigned) tags are now shown as references, and the
    builtin reference colors have been changed to highlight the
    current branch and the remote tracked by the current branch.
  o The status and stage views are now reloaded after running
    external commands (e.g. git commit) so they stay up to date.
  o A blame view has been added, and is accessible from the
    command line (tig blame [rev] file), status view, and the tree
    view (by pressing 'B').
- change compression to bzip2
* Mon Mar 17 2008 bwalle@suse.de
- update to 0.10
  o documentation improvements
  o bugfixes
  o needed updates to work better with git
  o On startup, tig will now attempt to first read a system-wide
    configuration file before loading the user specific
    configuration file.
  o Cherry picking from inside tig has been generalized
    making it possible to wire external commands, which can
    access information about the current commit, to a keybinding.
  o option parsing has been changed to be more similar to gitk's.
* Sat Sep 22 2007 bwalle@suse.de
- update to 0.9 (no upstream ChangeLog)
* Sun May 13 2007 bwalle@suse.de
- initial package
